package com.buy507.mall.mapper;

import com.buy507.mall.model.UmsMemberRelationTree;
import com.buy507.mall.model.UmsMemberRelationTreeExample;
import java.util.List;
import org.apache.ibatis.annotations.Param;

public interface UmsMemberRelationTreeMapper {
    long countByExample(UmsMemberRelationTreeExample example);

    int deleteByExample(UmsMemberRelationTreeExample example);

    int deleteByPrimaryKey(Long id);

    int insert(UmsMemberRelationTree record);

    int insertSelective(UmsMemberRelationTree record);

    List<UmsMemberRelationTree> selectByExample(UmsMemberRelationTreeExample example);

    UmsMemberRelationTree selectByPrimaryKey(Long id);

    int updateByExampleSelective(@Param("record") UmsMemberRelationTree record, @Param("example") UmsMemberRelationTreeExample example);

    int updateByExample(@Param("record") UmsMemberRelationTree record, @Param("example") UmsMemberRelationTreeExample example);

    int updateByPrimaryKeySelective(UmsMemberRelationTree record);

    int updateByPrimaryKey(UmsMemberRelationTree record);
}